import requests


class NvwaPredict(object):

    def __init__(self, host, port, endpoint):
        self.host = host
        self.port = port
        self.endpoint = endpoint

        self.dim_name = {
            "1": "AchievementOriented",
            "2": "Innovation",
            "3": "LearningAbility",
            "4": "Resilience",
            "5": "Execution",
            "6": "TeamWork",
        }

    def predict(self, doc_text, model_type: int):
        purl = f"{self.host}:{self.port}/{self.endpoint}"
        pdata = {
            "params": {
                "docText": doc_text,
                "model_type": model_type
            }
        }
        header = {
            "Content-Type": "application/json",
            "Auth": "dc5976de",
        }
        resp = requests.post(purl, json=pdata, headers=header)
        return resp.json()["result"]

    def predict_all(self, doc_text):
        pre_result = {}

        for i in range(1, 7):
            pre_score = self.predict(doc_text, i)
            pre_result[str(i)] = pre_score * 0.01
        return pre_result


if __name__ == '__main__':
    """
    1: AchievementOriented
    2: Innovation
    3: LearningAbility
    4: Resilience
    5: Execution
    6: TeamWork
    """

    # doc_text = "fgdgdg"
    # doc_text = "呃，这个好像嗯是一次。嗯，机械设计的课程设计，当时我们是要设计一个呃减速器。二级减速器，然后当时是呢，根据机械原理，做过的一次呃。呃，课程设计，然后把上把几元的课程设计的。嗯，方案用用，现在的一个方案去。呃，拍给具体的时间出来。然后机械原理的课程设计是嗯。嗯。呃，当时对机械设计不太了解，然后那个方案是做的有问题的。然后就在呃，机械设计呃。嗯。机械设计师的课程设计的时候，我们需要把它。呃方案给具体做出来的时候，嗯。呃，做出做最后做出来的呃。那个尺寸是呃有问题的不对的，然后我们就。对我我们就要去对那个方案进行重新重新的呃，纠正。然后。然后当时时间，嗯也有点紧可能呃去重新做也来不及了。然后就只能在原有的。呃，原有的词上面去呃修改，在原有图纸上面去修改。然后我喝。我就嗯。呃去。嗯。主导那个呃。方案的重新的一个修改和尺寸的重新的一个标定。最后还是用。哦哦。最后设计出来的还是。呃，符合一个课程设计的要求的。"
    # doc_text1 = "呃，这段经历的话，我想应该是。嗯，在我大三一开始的时候吧。因为大一大二前两年的成绩不是特别理想。然后大三大三的课程有很多都是专业的课程。然后自己就必须。嗯，非常努力的学习吧，因为。嗯，当时我也是自己给自己定下一个目标。就是平均分到85分就大三大三，这一年。平均分必须到85分。然后因为大二那一年平均分只有70分。70多分。然后，所以我感觉这个。嗯，幅度还还可以应该自己还是能实现的，然后后来就是每天。嗯。每天反正就起得很早，然后去上课去图书馆。然后一直去刷题。然后。因为前面的这个学习方法也不是特别好吧。在大三也是自己。嗯，具体找找到一些学习方法，然后。嗯，就是，最主要还是给自己定下的那个目标就是。平均85分吗。嗯，虽然85分也不是特别高，但是我感觉。嗯，对自己来说还还算是。呃，能够实现的一个小目标吧。然后最后我也是。嗯，最后平均分的话也是八十五八十五点儿。拔出的二分。大三这一年的平均分是85.28。嗯。包括什么，我们的专业课程编译原理。还有计算机网络。还有单片机等等都是90分以上。然后。这个经历我感觉也是。就自己只要努力。只要努力的话还是可以实现自己的目标。"
    doc_text1 = "我们当时做项目的时候有一个国际化就是做一个国际化版本，然后在开会的时候呢，其实呃开会，主要是他就是讲了一下一个简单的翻译工作就是我们是使用Internet Ling in te l包啊，Inter universal那个语言包来实现一整个项目的界面翻译，我发现的问题就是。比如说这个项目是属人属车，人脸识别和车牌识别，但是我们如果依据中国人的人脸识别去识别国外的，比如说国外有很多蓝眼睛啊什么但是这个会就是呃，我提出来这个问题，我觉得这样的人脸识别在国外，他是不可行的，还有国外的。呃，不过当时的重点是国外的身份证号就是人员信息不同，可是我觉得人的长相也是不同。就是中国的人脸识别放在国外是不行的。刚开始刚开始这个问题其实有很多人会提出异议，因为呃，因为它基本上是我们的人脸识别它基本上是比如说有没有戴口罩，没有戴眼镜，长头发短头发，然后什么眼睛是这样，他觉嗯，当时的意义是觉得全球是差不多的，可是，比如说国外他有很多会嘻哈范的他会戴帽子，但是中国的话就会比较少，其实很多，比如国外他不是会带那种嗯嗯，脸基尼吗。点击里它是嗯，就是跟国内的是不能匹配的。然后后来我我在会议上提出这个问题的时候，当时我们的项目经理啊，就觉得这个问题是应该要考虑，所以就呃把它计划到了第二个阶段应该开发的，所以第一个阶段是我市国际。的呃主要负责人之一，嗯呃，最后就是后来后来就是。嗯，通过，后来就是呃，有有换。就有患有会加一些外国人的一些人脸特征，还有一些外国人的一些穿着特征特征，就在国际化里面会把这一项目的特征搜索会跟国内版的不一样，最后就是功能上也会不一样，嗯，包括一些正则用正则表达去控制国外的啊时间，然后后来还加了一个。夏令时。呃，因为国外它有些地方是有夏令时的嗯。嗯，这个问题，最后是在第二个阶段解决的呃，也算是算是第一个阶段我提出来的问题。"
    nmodel = NvwaPredict("http://model.ai-open.hrtps.com", 80, "/models/NvWaChineseLeo/transfer")
    # pre = nmodel.predict(doc_text1, 1)
    pre = nmodel.predict_all(doc_text1)
    print(pre)

